@@ -374,32 +374,38 @@ nodoka_style_draw_box_gap (DRAW_ARGS, GtkPositionType gap_side, gint gap_x,
 				params.corners =
 					NDK_CORNER_BOTTOMRIGHT | NDK_CORNER_BOTTOMLEFT;
 
-				if (params.ltr) 
-					params.corners |= NDK_CORNER_TOPRIGHT;
-				else
-					params.corners |= NDK_CORNER_TOPLEFT;
+				if (frame.gap_width != width)
+					if (params.ltr) 
+						params.corners |= NDK_CORNER_TOPRIGHT;
+					else
+						params.corners |= NDK_CORNER_TOPLEFT;
 			}
 			else if (frame.gap_side == NDK_GAP_BOTTOM)
 			{
 				params.corners =
 					NDK_CORNER_TOPRIGHT | NDK_CORNER_TOPLEFT;
 
-				if (params.ltr) 
-					params.corners |= NDK_CORNER_BOTTOMRIGHT;
-				else
-					params.corners |= NDK_CORNER_BOTTOMLEFT;
+				if (frame.gap_width != width)
+					if (params.ltr) 
+						params.corners |= NDK_CORNER_BOTTOMRIGHT;
+					else
+						params.corners |= NDK_CORNER_BOTTOMLEFT;
 			}
 			else if (frame.gap_side == NDK_GAP_LEFT)
 			{
 				params.corners =
-					NDK_CORNER_BOTTOMLEFT | NDK_CORNER_BOTTOMRIGHT |
-					NDK_CORNER_TOPRIGHT;
+					NDK_CORNER_BOTTOMRIGHT | NDK_CORNER_TOPRIGHT;
+
+				if (frame.gap_width != height)
+					params.corners |= NDK_CORNER_BOTTOMLEFT;
 			}
 			else
 			{
 				params.corners =
-					NDK_CORNER_BOTTOMLEFT | NDK_CORNER_BOTTOMRIGHT |
-					NDK_CORNER_TOPLEFT;
+					NDK_CORNER_BOTTOMLEFT | NDK_CORNER_TOPLEFT;
+
+				if (frame.gap_width != height)
+					params.corners |= NDK_CORNER_BOTTOMRIGHT;
 			}
 		}
 
@@ -732,11 +738,16 @@ nodoka_style_draw_box (DRAW_ARGS)
 		slider.inverted = gtk_range_get_inverted (GTK_RANGE (widget));
 		slider.horizontal =
 			(GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL);
-		slider.fill_size =
-			((slider.horizontal ? width : height) -
-			 slider_length) * (1 / ((adjustment->upper - adjustment->lower) /
-									(adjustment->value - adjustment->lower))) +
-			slider_length / 2;
+		if ((adjustment->upper - adjustment->page_size - 
+                     adjustment->lower) != 0)
+			slider.fill_size = 
+				((slider.horizontal ? width : height) - 
+                                 slider_length) * 
+				((adjustment->value  - adjustment->lower) / 
+                                 (adjustment->upper - adjustment->page_size - 
+                                  adjustment->lower)) + slider_length / 2;
+		else
+			slider.fill_size = 0;
 		if (slider.horizontal)
 			slider.inverted =
 				slider.inverted != (nodoka_get_direction (widget) ==
